"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppModule = void 0;
const common_1 = require("@nestjs/common");
const app_controller_1 = require("./app.controller");
const app_service_1 = require("./app.service");
const config_1 = require("@nestjs/config");
const mongoose_1 = require("@nestjs/mongoose");
const nest_winston_1 = require("nest-winston");
const winston = require("winston");
const platform_express_1 = require("@nestjs/platform-express");
const user_module_1 = require("./user/user.module");
const jwt_1 = require("@nestjs/jwt");
const passport_1 = require("@nestjs/passport");
const commonServices_1 = require("./services/commonServices");
const authToken_schema_1 = require("./user/schema/authToken.schema");
const mailer_1 = require("@nestjs-modules/mailer");
const localAuth_1 = require("./user/localAuth");
const script_module_1 = require("./script/script.module");
const privacy_tc_schema_1 = require("./script/schema/privacy.tc.schema");
const video_thumbnail_service_1 = require("./services/video-thumbnail.service");
const scriptVideo_schema_1 = require("./script/schema/scriptVideo.schema");
let AppModule = class AppModule {
};
exports.AppModule = AppModule;
exports.AppModule = AppModule = __decorate([
    (0, common_1.Module)({
        imports: [
            config_1.ConfigModule.forRoot({ envFilePath: '.env', isGlobal: true }),
            jwt_1.JwtModule.register({
                global: true,
                secret: process.env.SECRET_KEY,
                signOptions: {},
            }),
            mailer_1.MailerModule.forRoot({
                transport: {
                    host: process.env.SENDGRID_HOST,
                    port: 587,
                    auth: {
                        user: process.env.SENDER_EMAIL,
                        pass: process.env.SENDGRID_SECRET_KEY,
                    },
                },
            }),
            platform_express_1.MulterModule.register({ dest: '../public' }),
            mongoose_1.MongooseModule.forRoot(process.env.DB_URL, { dbName: process.env.DBNAME }),
            mongoose_1.MongooseModule.forFeature([
                { name: 'auth-token', schema: authToken_schema_1.AuthTokenSchema },
                { name: 'privacy-term-condition', schema: privacy_tc_schema_1.PrivacyAndTermConditionSchema },
                { name: 'script-video', schema: scriptVideo_schema_1.ScriptVideoSchema },
            ]),
            passport_1.PassportModule.register({ defaultStrategy: 'jwt' }),
            nest_winston_1.WinstonModule.forRoot({
                format: winston.format.combine(winston.format.timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), winston.format.json()),
                transports: [
                    new winston.transports.File({
                        filename: 'logs/error.log',
                        level: 'error',
                    }),
                    new winston.transports.File({
                        filename: 'logs/info.log',
                        level: 'info',
                    }),
                ],
            }),
            user_module_1.UserModule,
            script_module_1.ScriptModule,
        ],
        controllers: [app_controller_1.AppController],
        providers: [app_service_1.AppService, commonServices_1.commonServices, localAuth_1.jwtStrategy, video_thumbnail_service_1.ScreenshotService],
        exports: [jwt_1.JwtModule, passport_1.PassportModule],
    })
], AppModule);
//# sourceMappingURL=app.module.js.map