"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScriptService = void 0;
const common_1 = require("@nestjs/common");
const commonServices_1 = require("../services/commonServices");
const winston_1 = require("winston");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const api_response_json_1 = require("../../api.response.json");
const video_thumbnail_service_1 = require("../services/video-thumbnail.service");
let ScriptService = class ScriptService {
    constructor(commonServices, screenshotService, PrivacyAndTermConditionModel, logger, ScriptModel, ScriptVideoModel) {
        this.commonServices = commonServices;
        this.screenshotService = screenshotService;
        this.PrivacyAndTermConditionModel = PrivacyAndTermConditionModel;
        this.logger = logger;
        this.ScriptModel = ScriptModel;
        this.ScriptVideoModel = ScriptVideoModel;
    }
    async addScript(scriptData, userId, script_video, res) {
        try {
            if (!script_video) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.videoRequired);
            }
            let isTitle = await this.ScriptModel.findOne({
                title: scriptData.title,
                userId: new mongoose_2.default.Types.ObjectId(userId),
            });
            if (isTitle) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.scriptExist);
            }
            let newScript = await this.ScriptModel.create({
                title: scriptData.title,
                description: scriptData.description,
                userId: new mongoose_2.default.Types.ObjectId(userId),
            });
            let screenShotPath = await this.screenshotService.takeScreenshot(script_video.path, './public/thumbnail', 1);
            let video_file = script_video.filename;
            let scriptVideo = await this.ScriptVideoModel.create({
                script_id: new mongoose_2.default.Types.ObjectId(newScript._id),
                video_file: video_file,
                duration: scriptData.duration,
                thumbnail: screenShotPath,
            });
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptCreate, { scriptData: newScript, scriptVideoData: scriptVideo });
        }
        catch (error) {
            console.log('Getting error while add script::', error);
            this.logger.error(`Getting error while add script, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async updateScript(userId, scriptData, res) {
        try {
            let isScript = await this.ScriptModel.findById(scriptData._id);
            if (!isScript) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.invalidScript);
            }
            if (isScript.title !== scriptData.title) {
                let isExist = await this.ScriptModel.findOne({
                    title: scriptData.title,
                    userId: new mongoose_2.default.Types.ObjectId(userId),
                });
                if (isExist) {
                    return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.scriptExist);
                }
            }
            let updateScript = await this.ScriptModel.findByIdAndUpdate(scriptData._id, { title: scriptData.title, description: scriptData.description }, { new: true });
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptUpdate, updateScript);
        }
        catch (error) {
            console.log('Getting error while update script', error);
            this.logger.error(`Getting error while update script , Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async deleteScript(_id, res) {
        try {
            let deleteScript = await this.ScriptModel.findByIdAndDelete(_id);
            if (!deleteScript) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.invalidScript);
            }
            let videoFile = await this.ScriptVideoModel.find({
                script_id: new mongoose_2.default.Types.ObjectId(_id),
            });
            videoFile.forEach(async (videoOBJ) => {
                let folder = 'videos';
                await this.commonServices.deleteFile(videoOBJ?.video_file, folder);
                folder = 'thumbnail';
                await this.commonServices.deleteFile(videoOBJ?.thumbnail, folder);
            });
            await this.ScriptVideoModel.deleteMany({
                script_id: new mongoose_2.default.Types.ObjectId(_id),
            });
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptDelete);
        }
        catch (error) {
            console.log('Getting error while delete script', error);
            this.logger.error(`Getting error while delete script , Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async getScriptById(userId, _id, res) {
        try {
            let scriptData = await this.ScriptModel.aggregate([
                {
                    $match: {
                        _id: new mongoose_2.default.Types.ObjectId(_id),
                        userId: new mongoose_2.default.Types.ObjectId(userId),
                    },
                },
                {
                    $lookup: {
                        from: 'script-videos',
                        localField: '_id',
                        foreignField: 'script_id',
                        as: 'videoData',
                    },
                },
                {
                    $project: {
                        _id: 1,
                        title: 1,
                        description: 1,
                        status: 1,
                        is_favorite: 1,
                        createdAt: 1,
                        script_videos: '$videoData',
                    },
                },
            ]);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptFetch, scriptData[0]);
        }
        catch (error) {
            console.log('Getting error while get script by id', error);
            this.logger.error(`Getting error while get script by id, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async getAllScript(userId, filterParams, res) {
        try {
            let search = filterParams.search || '';
            let sort = filterParams.order_by || 1;
            let query = {};
            console.log(filterParams.is_favorite);
            if (filterParams?.is_favorite === true) {
                query = {
                    userId: new mongoose_2.default.Types.ObjectId(userId),
                    is_favorite: true,
                };
            }
            else {
                query = { userId: new mongoose_2.default.Types.ObjectId(userId) };
            }
            let scriptData = await this.ScriptModel.aggregate([
                {
                    $match: query,
                },
                {
                    $match: {
                        $or: [{ title: { $regex: search, $options: 'i' } }],
                    },
                },
                {
                    $sort: { createdAt: sort },
                },
            ]);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptFetch, scriptData);
        }
        catch (error) {
            console.log('Getting error while get all script', error);
            this.logger.error(`Getting error while get all script, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async favoriteScript(userID, data, res) {
        try {
            let favoriteScript = await this.ScriptModel.findByIdAndUpdate(data._id, { is_favorite: data.is_favorite }, { new: true });
            if (!favoriteScript) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.invalidScript);
            }
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.addFavScript, favoriteScript);
        }
        catch (error) {
            console.log('Getting error while favorite script', error);
            this.logger.error(`Getting error while favorite script, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async addVideo(scriptData, videoDetails, res) {
        try {
            if (!videoDetails) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.videoRequired);
            }
            let isScript = await this.ScriptModel.findById(scriptData._id);
            if (!isScript) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.BAD_REQUEST, api_response_json_1.message.error.invalidScript);
            }
            let screenShotPath = await this.screenshotService.takeScreenshot(videoDetails.path, './public/thumbnail', 1);
            let videoData = await this.ScriptVideoModel.create({
                script_id: new mongoose_2.default.Types.ObjectId(scriptData._id),
                video_file: videoDetails.filename,
                duration: scriptData.duration,
                thumbnail: screenShotPath,
            });
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.scriptVideoAdd, videoData);
        }
        catch (error) {
            console.log('Getting error while add script video', error);
            this.logger.error(`Getting error while add script video, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
    async deleteScriptVideo(userId, data, res) {
        try {
            let isScriptVideo = await this.ScriptVideoModel.findById(data._id);
            if (isScriptVideo) {
                let folder = 'videos';
                await this.commonServices.deleteFile(isScriptVideo.video_file, folder);
                folder = 'thumbnail';
                await this.commonServices.deleteFile(isScriptVideo.thumbnail, folder);
            }
            let deleteVideo = await this.ScriptVideoModel.findByIdAndDelete(data._id);
            if (!deleteVideo) {
                return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.error.invalidVideoFile);
            }
            return this.commonServices.returnResponse(res, common_1.HttpStatus.OK, api_response_json_1.message.success.deleteScriptVideo);
        }
        catch (error) {
            console.log('Getting error while delete script video', error);
            this.logger.error(`Getting error while  delete script video, Reason:: ${error}`);
            return this.commonServices.returnResponse(res, common_1.HttpStatus.INTERNAL_SERVER_ERROR, api_response_json_1.message.error.serverError);
        }
    }
};
exports.ScriptService = ScriptService;
exports.ScriptService = ScriptService = __decorate([
    (0, common_1.Injectable)(),
    __param(2, (0, mongoose_1.InjectModel)('privacy-term-condition')),
    __param(3, (0, common_1.Inject)('winston')),
    __param(4, (0, mongoose_1.InjectModel)('script')),
    __param(5, (0, mongoose_1.InjectModel)('script-video')),
    __metadata("design:paramtypes", [commonServices_1.commonServices,
        video_thumbnail_service_1.ScreenshotService,
        mongoose_2.Model,
        winston_1.Logger,
        mongoose_2.Model,
        mongoose_2.Model])
], ScriptService);
//# sourceMappingURL=script.service.js.map